==> vss-ui-4.141.4.tgz: package/Components/Toggle/Toggle.js <==
import * as tslib_1 from "tslib";
import "../../Core/core.scss";
import "../../Common.scss";
import "./Toggle.scss";
import * as React from "react";
import { FocusZoneContext } from '../../FocusZone';
import { ObservableLike } from '../../Core/Observable';
import { css } from '../../Util';
var Toggle = /** @class */ (function (_super) {
    tslib_1.__extends(Toggle, _super);
    function Toggle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onCheckChange = function (checked) {
            _this.forceUpdate();
        };
        _this.onKeyDown = function (event) {
            if (!event.defaultPrevented) {
                if (event.which === 32 /* Space */) {
                    event.preventDefault();
                }
            }
        };
        _this.onKeyUp = function (event) {
            if (!event.defaultPrevented) {
                if (event.which === 32 /* Space */ || event.which === 13 /* Enter */) {
                    _this.onChange(event);
                    event.preventDefault();
                }
            }
        };
        _this.onChange = function (event) {
            if (_this.props.onChange) {
                _this.props.onChange(event, !ObservableLike.getValue(_this.props.checked));
            }
        };
        return _this;
    }
    Toggle.prototype.render = function () {
        var _this = this;
        var checked = this.props.checked && ObservableLike.getValue(this.props.checked);
        var _a = this.props, onAriaLabel = _a.onAriaLabel, offAriaLabel = _a.offAriaLabel, ariaLabel = _a.ariaLabel, className = _a.className, disabled = _a.disabled, excludeFocusZone = _a.excludeFocusZone, excludeTabStop = _a.excludeTabStop, id = _a.id, offText = _a.offText, onText = _a.onText, role = _a.role, text = _a.text;
        return (React.createElement(FocusZoneContext.Consumer, null, function (zoneContext) {
            var toggle = (React.createElement("div", { className: css(className, "bolt-toggle-button", checked && "checked", disabled ? "disabled" : "enabled"), onClick: _this.onChange, onKeyDown: _this.onKeyDown, onKeyUp: _this.onKeyUp },
                React.createElement("div", { "aria-checked": checked, "aria-disabled": disabled, "aria-label": checked ? onAriaLabel || ariaLabel : offAriaLabel || ariaLabel, "aria-pressed": checked, className: "bolt-toggle-button-pill bolt-focus-treatment", "data-focuszone": !disabled && !excludeFocusZone ? zoneContext.focuszoneId : undefined, id: id, role: role || "switch", tabIndex: !disabled && !excludeTabStop ? 0 : undefined },
                    React.createElement("div", { className: "bolt-toggle-button-icon" })),
                React.createElement("div", { className: "bolt-toggle-button-text" }, checked ? onText || text : offText || text)));
            return toggle;
        }));
    };
    Toggle.prototype.componentDidMount = function () {
        ObservableLike.subscribe(this.props.checked, this.onCheckChange);
    };
    Toggle.prototype.componentWillUnmount = function () {
        ObservableLike.unsubscribe(this.props.checked, this.onCheckChange);
    };
    return Toggle;
}(React.Component));
export { Toggle };

==> vss-ui-4.142.1.tgz: package/Components/Toggle/Toggle.js <==
import * as tslib_1 from "tslib";
import "../../Core/core.scss";
import "../../Common.scss";
import "./Toggle.scss";
import * as React from "react";
import { ObservableLike } from '../../Core/Observable';
import { FocusZoneContext } from '../../FocusZone';
import { Tooltip } from '../../TooltipEx';
import { css } from '../../Util';
var Toggle = /** @class */ (function (_super) {
    tslib_1.__extends(Toggle, _super);
    function Toggle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onCheckChange = function (checked) {
            _this.forceUpdate();
        };
        _this.onKeyDown = function (event) {
            if (!event.defaultPrevented) {
                if (event.which === 32 /* Space */) {
                    event.preventDefault();
                }
            }
        };
        _this.onKeyUp = function (event) {
            if (!event.defaultPrevented) {
                if (event.which === 32 /* Space */ || event.which === 13 /* Enter */) {
                    _this.onChange(event);
                    event.preventDefault();
                }
            }
        };
        _this.onChange = function (event) {
            if (_this.props.onChange && !_this.props.disabled) {
                _this.props.onChange(event, !ObservableLike.getValue(_this.props.checked));
            }
        };
        return _this;
    }
    Toggle.prototype.render = function () {
        var _this = this;
        var checked = this.props.checked && ObservableLike.getValue(this.props.checked);
        var _a = this.props, onAriaLabel = _a.onAriaLabel, offAriaLabel = _a.offAriaLabel, ariaLabel = _a.ariaLabel, className = _a.className, disabled = _a.disabled, excludeFocusZone = _a.excludeFocusZone, excludeTabStop = _a.excludeTabStop, id = _a.id, offText = _a.offText, onText = _a.onText, role = _a.role, text = _a.text, tooltipProps = _a.tooltipProps;
        return (React.createElement(FocusZoneContext.Consumer, null, function (zoneContext) {
            var toggle = (React.createElement("div", { className: css(className, "bolt-toggle-button", checked && "checked", disabled ? "disabled" : "enabled"), onClick: _this.onChange, onKeyDown: _this.onKeyDown, onKeyUp: _this.onKeyUp },
                React.createElement("div", { "aria-checked": checked, "aria-disabled": disabled, "aria-label": checked ? onAriaLabel || ariaLabel : offAriaLabel || ariaLabel, "aria-pressed": checked, className: "bolt-toggle-button-pill bolt-focus-treatment", "data-focuszone": !disabled && !excludeFocusZone ? zoneContext.focuszoneId : undefined, "data-is-focusable": true, id: id, role: role || "switch", tabIndex: !disabled && !excludeTabStop ? 0 : undefined },
                    React.createElement("div", { className: "bolt-toggle-button-icon" })),
                React.createElement("div", { className: "bolt-toggle-button-text" }, checked ? onText || text : offText || text)));
            if (tooltipProps) {
                toggle = React.createElement(Tooltip, tslib_1.__assign({}, tooltipProps), toggle);
            }
            return toggle;
        }));
    };
    Toggle.prototype.componentDidMount = function () {
        ObservableLike.subscribe(this.props.checked, this.onCheckChange);
    };
    Toggle.prototype.componentWillUnmount = function () {
        ObservableLike.unsubscribe(this.props.checked, this.onCheckChange);
    };
    return Toggle;
}(React.Component));
export { Toggle };
